@@ -12,7 +12,7 @@ class Multiplexer:
         self.bipot = bipot
         self.channels = channels
 
-    def open(self):    
+      
         dataframe = pd.read_csv(self.filepath, sep = ',', header = 5, encoding = "utf16", low_memory = False)
         newdataframe = dataframe.dropna()
         array = newdataframe.to_numpy().astype(float)
@@ -28,9 +28,7 @@ class Multiplexer:
         
         newarray = np.empty((self.channels,experiments,fields,rows))
 
-        for x in range(0, self.channels):
-            for y in range(0,experiments):
-                for z in range(0,fields):
-                    newarray[x,y,z,:] = array[:,(z+(experiments*y)+(fields*x))]
+        for x,y,z in np.ndindex((channels,experiments,fields)):
+            newarray[x,y,z,:] = array[:,(z+(channels*y)+(fields*x))]
         
-        return newarray    
\ No newline at end of file
+        self.array = newarray    
\ No newline at end of file
